SystemOrganization addCategory: #'HM4-PokerDice'!

TestCase subclass: #PokerDiceGameTest
	instanceVariableNames: 'newGame'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameTest commentStamp: 'CameronRieck 2/25/2013 17:57' prior: 0!
A test suite for testing the game state transitions for PokerDiceGame.

Instance Variables:
	newGame	<PokerDiceGameModel> 		An instance of a new game to test with.!

!PokerDiceGameTest methodsFor: 'running' stamp: 'CameronRieck 2/25/2013 17:55'!
setUp
	newGame := PokerDiceGameModel new.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testNewGameConditions
	self assert: newGame creditsRemaining = PokerDiceGameModel startingCredits.
	self assert: newGame throwsInRoundRemaining = PokerDiceGameModel throwsPerRound.
	self assert: newGame currentRound = 1.
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testPayPlayer
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 2 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (PokerDiceGameModel startingCredits - PokerDiceGameModel costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.
	! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testPlayTwoRounds
	| hand round1StartingCredits round2StartingCredits |
	hand := Hand new.
	
	hand fixDice: #(2 2 2 2 1).
	round1StartingCredits := newGame creditsRemaining.
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 2 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (round1StartingCredits - PokerDiceGameModel costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.
	
	hand fixDice: #(2 2 2 1 1).
	round2StartingCredits := newGame creditsRemaining.
	1 to: 2 do: [ :i | newGame playerThrew ].
	newGame fixHand: #(2 2 2 1 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 2).
	self assert: (newGame creditsRemaining) = (round2StartingCredits - PokerDiceGameModel costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testThrowFourTimes
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 4 do: [ :i | newGame fixHand: #(2 2 2 2 1).  newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGameModel throwsPerRound - 1).
	self assert: (newGame currentRound = 2).
	self assert: (newGame creditsRemaining) = ((PokerDiceGameModel startingCredits) + (hand payout) - (PokerDiceGameModel costToPlayRound) - (PokerDiceGameModel costToPlayRound)).
	self assert: newGame playerCanSelectDice = true.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testThrowOnce
	newGame playerThrew.
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGameModel throwsPerRound - 1).
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = true.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testThrowThreeTimes
	| hand |
	hand := Hand new.
	hand fixDice: #(2 2 2 2 1).
	1 to: 3 do: [ :i | newGame fixHand: #(2 2 2 2 1).  newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGameModel throwsPerRound - 3).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGameModel throwsPerRound - 3).
	self assert: (newGame currentRound = 1).
	self assert: (newGame creditsRemaining) = (PokerDiceGameModel startingCredits - PokerDiceGameModel costToPlayRound + hand payout).
	self assert: newGame playerCanSelectDice = false.! !

!PokerDiceGameTest methodsFor: 'tests' stamp: 'CameronRieck 2/25/2013 17:55'!
testThrowTwice
	| hand |
	hand := Hand new.
	1 to: 2 do: [ :i | newGame playerThrew ].
	self assert: (newGame throwsInRoundRemaining) = (PokerDiceGameModel throwsPerRound - 2).
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = true.
	newGame playerAcceptsPayment.
	self assert: (newGame throwsInRoundRemaining) = 0.
	self assert: (newGame currentRound = 1).
	self assert: newGame playerCanSelectDice = false.
	! !

DieView subclass: #GameDieView
	instanceVariableNames: 'marked canBeMarked'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameDieView commentStamp: 'CameronRieck 2/25/2013 17:50' prior: 0!
Visually represents a die.  Extends from DieView to enable marking with the right mouse button.

Instance Variables:
	marked			<Boolean>		Indicates that the Die has been marked by the user.
	canBeMarked	<Boolean>		Indicates that the Die is allowed to be marked by the user.!

!GameDieView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:52'!
disableMarking
	canBeMarked := false.
	self unmark.! !

!GameDieView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:50'!
enableMarking
	canBeMarked := true.! !

!GameDieView methodsFor: 'event handling' stamp: 'CameronRieck 2/24/2013 19:50'!
handlesMouseDown: evt
	canBeMarked
		ifTrue: [ ^ super handlesMouseDown: evt ]
		ifFalse: [ ^ canBeMarked ]
	! !

!GameDieView methodsFor: 'initialization' stamp: 'CameronRieck 2/24/2013 19:50'!
initialize
	super initialize.
	marked := false.
	canBeMarked := true.! !

!GameDieView methodsFor: 'testing' stamp: 'CameronRieck 2/21/2013 14:10'!
isMarked
	^ marked.! !

!GameDieView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:10'!
mark
	marked := true.
	self updateMarking.! !

!GameDieView methodsFor: 'event handling' stamp: 'CameronRieck 2/21/2013 14:05'!
mouseDown: event 
	marked := marked not.
	self updateMarking.! !

!GameDieView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:10'!
unmark
	marked := false.
	self updateMarking.! !

!GameDieView methodsFor: 'private' stamp: 'CameronRieck 2/21/2013 14:16'!
updateMarking
	marked
	ifTrue: [ self borderColor: Color yellow ; color: Color blue ] 
	ifFalse: [ self borderColor: Color black ; color: self defaultColor ]! !

SimpleButtonMorph subclass: #PokerDiceGameButton
	instanceVariableNames: 'enabled'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameButton commentStamp: 'CameronRieck 2/25/2013 17:38' prior: 0!
Represents a game control button in the PokerDiceGamePlayer.

Instance Variables:
	enabled	<Boolean>		Indicates if the button should be clickable or not.!

!PokerDiceGameButton methodsFor: 'actions' stamp: 'CameronRieck 2/25/2013 13:55'!
disable
	enabled := false.
	self color: Color lightGray.! !

!PokerDiceGameButton methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:34'!
enable
	enabled := true.
	self color: Color green.! !

!PokerDiceGameButton methodsFor: 'event handling' stamp: 'CameronRieck 2/24/2013 19:27'!
handlesMouseDown: evt
	^ enabled! !

!PokerDiceGameButton methodsFor: 'initialization' stamp: 'CameronRieck 2/24/2013 19:34'!
initialize
	super initialize.
	self enable.! !

AlignmentMorph subclass: #GameBannerView
	instanceVariableNames: 'banner'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameBannerView commentStamp: 'CameronRieck 2/25/2013 17:54' prior: 0!
Represents the banner at the top of the game showing the name of the game.

Instance Variables:
	banner		<StringMorph>		The string representing the banner at the top.!

!GameBannerView methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 17:12'!
initialize
	super initialize.
	banner := (StringMorph new) contents: 'Poker Dice'.
	banner hResizing: #shrinkWrap.
	banner wrapCentering: #center.
	banner cellPositioning: #center.
	self addMorphBack: banner.
	self hResizing: #shrinkWrap.
	self wrapCentering: #center.
	self cellPositioning: #center.! !

AlignmentMorph subclass: #GameBoardView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameBoardView commentStamp: 'CameronRieck 2/25/2013 17:53' prior: 0!
Visually represents the game board and is used to add all of the other visual element categories on to.!

!GameBoardView methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 17:08'!
initialize
	super initialize.
	self borderWidth: 1.
	self shrinkWrap.
	self cornerStyle: #rounded.
	self hResizing: #shrinkWrap.
	self wrapCentering: #center.
	self cellPositioning: #center.! !

!GameBoardView methodsFor: 'formatting' stamp: 'CameronRieck 2/25/2013 17:08'!
shrinkWrap
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self wrapCentering: #center.
	self cellPositioning: #center.! !

AlignmentMorph subclass: #GameControlView
	instanceVariableNames: 'throwButton acceptPaymentButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameControlView commentStamp: 'CameronRieck 2/25/2013 17:52' prior: 0!
Visually represents the controls of the game such as throwing the dice and accepting payment for the round.

Instance Variables:
	throwButton			<PokerDiceGameButton>		Button that, when pushed, throws the unmarked dice.
	acceptPaymentButton	<PokerDiceGameButton>		Button that, when pushed, credits the player with the current hand payout and ends the round.!

!GameControlView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:35'!
disableAcceptButton
	acceptPaymentButton disable.! !

!GameControlView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:35'!
disableThrowButton
	throwButton disable.! !

!GameControlView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:35'!
enableAcceptButton
	acceptPaymentButton enable.! !

!GameControlView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:35'!
enableThrowButton
	throwButton enable.! !

!GameControlView methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 13:39'!
initialize
	| buttonColumn |
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.
	
	buttonColumn := (AlignmentMorph newColumn).
	buttonColumn cornerStyle: #rounded.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	acceptPaymentButton := PokerDiceGameButton newWithLabel: 'accept payment'.
	acceptPaymentButton cornerStyle: #rounded.
	buttonColumn addMorphBack: acceptPaymentButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	throwButton := PokerDiceGameButton newWithLabel: 'throw dice'.
	throwButton cornerStyle: #rounded.
	buttonColumn addMorphBack: throwButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (buttonColumn defaultColor)).
	self addMorphBack: buttonColumn.! !

!GameControlView methodsFor: 'initialization' stamp: 'CameronRieck 2/23/2013 15:46'!
setAcceptPaymentButtonTarget: target atSelector: selector
	acceptPaymentButton target: target; actionSelector: selector.! !

!GameControlView methodsFor: 'initialization' stamp: 'CameronRieck 2/23/2013 13:34'!
setThrowButtonTarget: target atSelector: selector
	throwButton target: target; actionSelector: selector.! !

AlignmentMorph subclass: #GameDiceView
	instanceVariableNames: 'game dieViews'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameDiceView commentStamp: 'CameronRieck 2/25/2013 17:55' prior: 0!
Visually represents the collection of dice to be shown on the game board.

Instance Variables:
	game		<PokerDiceGameModel>		A reference to the game being played.
	dieViews	<(Array of: GameDieView)>		An array of die views to show.!

!GameDiceView class methodsFor: 'instance creation' stamp: 'CameronRieck 2/22/2013 21:10'!
makeFromHand: aHand
	
"	buttonColumn := (AlignmentMorph newColumn).
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	newGameButton := SimpleButtonMorph newWithLabel: 'new game'.
	buttonColumn addMorphBack: newGameButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	throwButton := SimpleButtonMorph newWithLabel: 'throw dice'.
	buttonColumn addMorphBack: throwButton.
	buttonColumn addMorphBack: (AlignmentMorph newSpacer: (Color gray)).
	self addMorphBack: buttonColumn."! !

!GameDiceView methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 13:38'!
initialize
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.! !

!GameDiceView methodsFor: 'initialization' stamp: 'CameronRieck 2/24/2013 19:54'!
setGame: aGame
	game := aGame.
	dieViews := Array new: (game handSize).
	1 to: game handSize do: [ :i | dieViews at: i put: GameDieView new ].
	1 to: game handSize do: [ :i | (dieViews at: i) model: (game hand dice at: i) ].
	1 to: game handSize do: [ :i | self addMorphBack: (dieViews at: i) ].
	self update.! !

!GameDiceView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:09'!
throwDice
	game playerCanSelectDice 
		ifTrue: [1 to: game handSize do: [ :i | (dieViews at: i) isMarked ifFalse: [ (dieViews at: i) throwDie ] ]]
		ifFalse: [1 to: game handSize do: [ :i | (dieViews at: i) throwDie ]].
	! !

!GameDiceView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:43'!
unmarkDice
		1 to: game handSize do: [ :i | (dieViews at: i) unmark ].
	! !

!GameDiceView methodsFor: 'private' stamp: 'CameronRieck 2/24/2013 19:52'!
update
	game playerCanSelectDice
		ifTrue: [ 1 to: game handSize do: [ :i | (dieViews at: i) enableMarking ] ]
		ifFalse: [ 1 to: game handSize do: [ :i | (dieViews at: i) disableMarking ] ]
	! !

AlignmentMorph subclass: #GameStateView
	instanceVariableNames: 'roundLabel roundData throwsLabel throwsData creditLabel creditData game payoutLabel payoutData'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!GameStateView commentStamp: 'CameronRieck 2/25/2013 17:56' prior: 0!
Visually represents the widgets that show the state of the game being played.

Instance Variables:
	roundLabel		<StringMorph>					The label for the current round.
	roundData		<StringMorph>					Shows the current round number.
	throwsLabel	<StringMorph>					The label for throws remaining.
	throwsData		<StringMorph>					Shows the number of throws remaining in the round.
	creditLabel		<StringMorph>					The label for the amount of credit remaining.
	creditData		<StringMorph>					Shows the amount of credit remaining for the player.
	payoutLabel	<StringMorph>					The label for the payout value of the current hand.
	payoutData		<StringMorph>					Shows the payout value of the current hand.
	game			<PokerDiceGameModel>		A reference to the Poker Dice Game being played.
!

!GameStateView methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 13:42'!
initialize
	| titleColumn dataColumn |
	super initialize.
	self hResizing: #shrinkWrap.
	self vResizing: #shrinkWrap.
	self cornerStyle: #rounded.
	
	titleColumn := (AlignmentMorph newColumn).
	titleColumn cornerStyle: #rounded.
	roundLabel := (StringMorph new) contents: 'round'.
	titleColumn addMorphBack: (self wrapInContainer: roundLabel).
	throwsLabel := (StringMorph new) contents: 'throws remaining'.
	titleColumn addMorphBack: (self wrapInContainer: throwsLabel).
	creditLabel := (StringMorph new) contents: 'credit'.
	titleColumn addMorphBack: (self wrapInContainer: creditLabel).
	payoutLabel := (StringMorph new) contents: 'hand payout'.
	titleColumn addMorphBack: (self wrapInContainer: payoutLabel).
	self addMorphBack: titleColumn.
	
	dataColumn := AlignmentMorph newColumn.
	dataColumn cornerStyle: #rounded.
	roundData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: roundData).
	throwsData :=  (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: throwsData).
	creditData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: creditData).
	payoutData := (StringMorph new) contents: ''.
	dataColumn addMorphBack: (self wrapInContainer: payoutData).
	self addMorphBack: dataColumn.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/23/2013 13:29'!
setCredits: credits
	creditData contents: credits asString.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/23/2013 13:30'!
setCurrentRound: round
	roundData contents: round asString.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:12'!
setGame: aGame.
	game := aGame.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 20:30'!
setHandPayout: payout
	payoutData contents: payout asString.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/23/2013 13:30'!
setThrowsRemaining: throws
	throwsData contents: throws asString.! !

!GameStateView methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 20:30'!
update
	self setCredits: game creditsRemaining.
	self setCurrentRound: game currentRound.
	self setThrowsRemaining: game throwsInRoundRemaining.
	self setHandPayout: game hand payout.! !

!GameStateView methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 20:47'!
wrapInContainer: aMorph
	^ ((AlignmentMorph newRow) borderWidth: 2) addMorph: aMorph.! !

Object subclass: #PokerDiceGameModel
	instanceVariableNames: 'hand currentState oneState twoState threeState zeroState acceptState creditsRemaining roundsPlayed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameModel commentStamp: 'CameronRieck 2/25/2013 17:37' prior: 0!
Represents the poker dice game.  Initializes the game state (starting credits, rounds played, initial state, hand).

Instance Variables:
	hand				<Hand>					The poker hand representation.
	currentState		<PokerDiceGameState>	The current poker game state.
	oneState			<PokerDiceGameState>	Instance of the state representing one throw left left in the round.
	twoState			<PokerDiceGameState>	Instance of the state representing two throws left left in the round.
	threeState			<PokerDiceGameState>	Instance of the state representing three throws left left in the round.
	zeroState			<PokerDiceGameState>	Instance of the state representing zero throws left in the round.
	acceptState		<PokerDiceGameState>	Instance of the state representing the player has been paid for the round.
	creditsRemaining	<Number>					The number of credits remaining.
	roundsPlayed		<Number>					The number of rounds played so far.!

!PokerDiceGameModel class methodsFor: 'constants' stamp: 'CameronRieck 2/22/2013 14:22'!
costToPlayRound
	^ 10! !

!PokerDiceGameModel class methodsFor: 'constants' stamp: 'CameronRieck 2/22/2013 13:46'!
startingCredits
	^ 100! !

!PokerDiceGameModel class methodsFor: 'constants' stamp: 'CameronRieck 2/22/2013 13:49'!
throwsPerRound
	^ 3! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/24/2013 18:44'!
acceptState
	^ acceptState! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:55'!
chargePlayerForRound
	creditsRemaining := creditsRemaining - PokerDiceGameModel costToPlayRound! !

!PokerDiceGameModel methodsFor: 'game state' stamp: 'CameronRieck 2/22/2013 13:44'!
creditsRemaining
	^ creditsRemaining! !

!PokerDiceGameModel methodsFor: 'game state' stamp: 'CameronRieck 2/22/2013 14:05'!
currentRound
	^ roundsPlayed + 1! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/23/2013 15:10'!
currentState
	^ currentState! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:26'!
fixHand: diceValues
	hand fixDice: diceValues! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/21/2013 18:47'!
hand
	^ hand! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/23/2013 15:41'!
handSize
	^ hand dice size! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:05'!
incrementRound
	roundsPlayed := roundsPlayed + 1.! !

!PokerDiceGameModel methodsFor: 'initialization' stamp: 'CameronRieck 2/24/2013 18:44'!
initialize
	super initialize.
	threeState := (ThreeThrowsRemainingState new) setGame: self.
	twoState := (TwoThrowsRemainingState new) setGame: self.
	oneState := (OneThrowRemainingState new) setGame: self.
	zeroState := (ZeroThrowsRemainingState new) setGame: self.
	acceptState := (PlayerAcceptedPaymentState new) setGame: self.
	currentState := threeState.
	
	self resetHand.
	self resetCreditsRemaining.
	self resetRoundsPlayed.! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/23/2013 15:01'!
oneState
	^ oneState! !

!PokerDiceGameModel methodsFor: 'game control' stamp: 'CameronRieck 2/24/2013 18:48'!
playerAcceptsPayment
	currentState accept! !

!PokerDiceGameModel methodsFor: 'game state' stamp: 'CameronRieck 2/24/2013 19:02'!
playerCanSelectDice
	^ currentState playerCanSelectDice! !

!PokerDiceGameModel methodsFor: 'game control' stamp: 'CameronRieck 2/23/2013 14:54'!
playerThrew
	currentState throw! !

!PokerDiceGameModel methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 17:55'!
resetCreditsRemaining
	creditsRemaining := PokerDiceGameModel startingCredits! !

!PokerDiceGameModel methodsFor: 'initialization' stamp: 'CameronRieck 2/23/2013 15:39'!
resetHand
	hand := Hand new! !

!PokerDiceGameModel methodsFor: 'initialization' stamp: 'CameronRieck 2/22/2013 14:09'!
resetRoundsPlayed
	roundsPlayed := 0! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/23/2013 15:03'!
setGameState: aGameState
	currentState := aGameState! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/23/2013 15:01'!
threeState
	^ threeState! !

!PokerDiceGameModel methodsFor: 'game state' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsInRoundRemaining
	^ currentState throwsRemaining! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/23/2013 15:01'!
twoState
	^ twoState! !

!PokerDiceGameModel methodsFor: 'private' stamp: 'CameronRieck 2/22/2013 14:23'!
updateCreditsWithCurrentPayout
	creditsRemaining := creditsRemaining + hand payout.! !

!PokerDiceGameModel methodsFor: 'throw states' stamp: 'CameronRieck 2/23/2013 15:01'!
zeroState
	^ zeroState! !

Object subclass: #PokerDiceGamePlayer
	instanceVariableNames: 'game gameStateView gameControlView gameDiceView gameBoardView gameBannerView'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGamePlayer commentStamp: 'CameronRieck 2/25/2013 17:56' prior: 0!
Brings together the PokerDiceGame and all the views showing and manipulating the game state.

Instance Variables:
	game				<PokerDiceGameModel>		The model of the Poker Dice game.
	gameStateView	<GameStateView>				A widget showing the game state.
	gameControlView	<GameControlView>			A widget showing the game controls.
	gameDiceView		<GameDiceView>				A widget showing the dice.
	gameBoardView	<GameBoardView>				A widget that represents the game board where all the other widgets are attached to.
	gameBannerView	<GameBannerView>			A widget that shows the title of the game at the top.!

!PokerDiceGamePlayer class methodsFor: 'instance creation' stamp: 'CameronRieck 2/25/2013 17:03'!
withGame: aGame
	| newView |
	newView := PokerDiceGamePlayer new.
	newView setGame: aGame.
	^ newView.! !

!PokerDiceGamePlayer class methodsFor: 'instance creation' stamp: 'CameronRieck 2/25/2013 17:55'!
withNewGame
	| newView |
	newView := PokerDiceGamePlayer new.
	newView setGame: (PokerDiceGameModel new).
	^ newView.! !

!PokerDiceGamePlayer methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:47'!
acceptPaymentButtonPressed
	game playerAcceptsPayment.
	gameStateView update.
	gameDiceView update.
	gameControlView disableAcceptButton.
	gameControlView enableThrowButton.! !

!PokerDiceGamePlayer methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:01'!
addBanner
	gameBannerView := GameBannerView newRow.
	gameBoardView addMorphBack: gameBannerView.! !

!PokerDiceGamePlayer methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:01'!
addBoard
	gameBoardView := GameBoardView newColumn.
	gameBoardView shrinkWrap! !

!PokerDiceGamePlayer methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:02'!
addControls
	gameControlView := GameControlView newRow.
	gameControlView disableAcceptButton.
	gameControlView enableThrowButton.
	gameControlView setThrowButtonTarget: self atSelector: #throwButtonPressed.
	gameControlView setAcceptPaymentButtonTarget: self atSelector: #acceptPaymentButtonPressed.
	gameBoardView addMorphBack: gameControlView! !

!PokerDiceGamePlayer methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:02'!
addDice
	gameDiceView := GameDiceView newRow.
	gameDiceView setGame: game.
	gameBoardView addMorphBack: gameDiceView! !

!PokerDiceGamePlayer methodsFor: 'private' stamp: 'CameronRieck 2/25/2013 17:02'!
addGameState
	gameStateView := GameStateView newRow.
	gameStateView setGame: game.
	gameStateView setThrowsRemaining: game throwsInRoundRemaining.
	gameStateView setCredits: game creditsRemaining.
	gameStateView setCurrentRound: game currentRound.
	gameBoardView addMorphBack: gameStateView! !

!PokerDiceGamePlayer methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 17:00'!
initialize
	super initialize.! !

!PokerDiceGamePlayer methodsFor: 'initialization' stamp: 'CameronRieck 2/25/2013 17:03'!
setGame: aGame
	game := aGame.
	self addBoard.
	self addBanner.
	self addGameState.
	self addControls.
	self addDice! !

!PokerDiceGamePlayer methodsFor: 'actions' stamp: 'CameronRieck 2/25/2013 13:49'!
show
	gameBoardView openInWorld.! !

!PokerDiceGamePlayer methodsFor: 'actions' stamp: 'CameronRieck 2/24/2013 19:39'!
throwButtonPressed
	gameDiceView throwDice.
	game playerThrew.
	gameStateView update.
	gameDiceView update.
	gameControlView enableAcceptButton.
	(game throwsInRoundRemaining = 0)
		ifTrue: [ gameControlView disableThrowButton ].! !

Object subclass: #PokerDiceGameState
	instanceVariableNames: 'game'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PokerDiceGameState commentStamp: 'CameronRieck 2/25/2013 17:56' prior: 0!
Represents a state in the PokerDiceGame.  Uses the state pattern.

Instance Variables:
	game	<PokerDiceGameModel>		A reference to the PokerDiceGame being played.!

PokerDiceGameState subclass: #OneThrowRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!OneThrowRemainingState commentStamp: 'CameronRieck 2/25/2013 17:43' prior: 0!
Represents the state where the player has one more throw remaining in the round.!

!OneThrowRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:44'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!OneThrowRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:01'!
playerCanSelectDice
	^ true! !

!OneThrowRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 15:02'!
throw
	game setGameState: game zeroState.! !

!OneThrowRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	^ 1! !

PokerDiceGameState subclass: #PlayerAcceptedPaymentState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!PlayerAcceptedPaymentState commentStamp: 'CameronRieck 2/25/2013 17:44' prior: 0!
Represents the state where the player has accepted payment for the hand he/she has.!

!PlayerAcceptedPaymentState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 16:35'!
accept
! !

!PlayerAcceptedPaymentState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:00'!
playerCanSelectDice
	^ false! !

!PlayerAcceptedPaymentState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:35'!
throw
	game chargePlayerForRound.
	game incrementRound.
	game setGameState: game twoState.! !

!PlayerAcceptedPaymentState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 16:36'!
throwsRemaining
	^ 0! !

!PokerDiceGameState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 14:40'!
accept
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:00'!
playerCanSelectDice
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'initialization' stamp: 'CameronRieck 2/23/2013 14:37'!
setGame: aGame
	game := aGame! !

!PokerDiceGameState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 14:40'!
throw
	self subclassResponsibility! !

!PokerDiceGameState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	self subclassResponsibility! !

PokerDiceGameState subclass: #ThreeThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!ThreeThrowsRemainingState commentStamp: 'CameronRieck 2/25/2013 17:44' prior: 0!
Represents the state where the player has three more throws remaining in the round.!

!ThreeThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 16:01'!
accept
	! !

!ThreeThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:45'!
playerCanSelectDice
	^ false! !

!ThreeThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:33'!
throw
	game chargePlayerForRound.
	game setGameState: game twoState.! !

!ThreeThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 15:04'!
throwsRemaining
	^ 3! !

PokerDiceGameState subclass: #TwoThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!TwoThrowsRemainingState commentStamp: 'CameronRieck 2/25/2013 17:44' prior: 0!
Represents the state where the player has two more throws remaining in the round.!

!TwoThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:45'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!TwoThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:01'!
playerCanSelectDice
	^ true! !

!TwoThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/23/2013 15:02'!
throw
	game setGameState: game oneState.! !

!TwoThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 15:05'!
throwsRemaining
	^ 2! !

PokerDiceGameState subclass: #ZeroThrowsRemainingState
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'HM4-PokerDice'!

!ZeroThrowsRemainingState commentStamp: 'CameronRieck 2/25/2013 17:44' prior: 0!
Represents the state where the player has no more throws remaining in the round.!

!ZeroThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:45'!
accept
	game updateCreditsWithCurrentPayout.
	game setGameState: game acceptState.! !

!ZeroThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/24/2013 19:45'!
playerCanSelectDice
	^ true! !

!ZeroThrowsRemainingState methodsFor: 'transitions' stamp: 'CameronRieck 2/24/2013 18:33'!
throw
	game playerAcceptsPayment.
	game chargePlayerForRound.
	game incrementRound.
	game setGameState: game twoState.! !

!ZeroThrowsRemainingState methodsFor: 'information' stamp: 'CameronRieck 2/23/2013 15:05'!
throwsRemaining
	^ 0! !
